import React, { useEffect, useState } from "react";
import Api from "../utils/api";
import TextField from "@material-ui/core/TextField";
import Grid from "@material-ui/core/Grid";
import Toolbar from "@material-ui/core/Toolbar";
import Autocomplete from "@material-ui/lab/Autocomplete";
import { ResponsiveLine } from "@nivo/line";
import mean from "lodash/mean";
import Container from "@material-ui/core/Container";

const queryBuilder = ({ filter }) => {
  return `q={${filter ? `"year": ${filter}` : ""}}`;
};

const Chart = () => {
  const [years, setYears] = useState([]);
  const [data, setData] = useState([]);
  const [filter, setFilter] = useState(undefined);
  const [initialized, setInitialized] = useState(false);

  const onFilter = (_e, filter) => {
    setFilter(filter);
  };

  useEffect(() => {
    Api.get(`rest/sunshine?q={}&h={"$fields": {"year": 1}}`).then((data) => setYears([...new Set(data.map(({ year }) => `${year}`))]));
  }, []);

  useEffect(() => {
    setInitialized(false);
    if (filter) {
      Api.get(`rest/sunshine?${queryBuilder({ filter })}`).then((data) => {
        setData(data);
        setInitialized(true);
      });
    }
  }, [filter]);

  const chartData = data.map(({ _id, year, month, ...item }) => ({
    x: month,
    y: mean(Object.values(item))
  }));

  return (
    <div style={{ height: "100%" }}>
      <h1>Average sunshine in a month - start by selecting a year</h1>
      <Toolbar>
        <Grid container spacing={3} justify="space-between">
          <Grid item>
            <Autocomplete
              style={{ minWidth: "150px" }}
              options={years}
              id="year-picker"
              value={filter}
              onChange={onFilter}
              renderInput={(params) => <TextField {...params} label="Select year" margin="normal" />}
            />
          </Grid>
        </Grid>
      </Toolbar>
      {initialized && (
        <ResponsiveLine
          data={[
            {
              id: "sunshine",
              color: "hsl(95, 70%, 50%)",
              data: chartData
            }
          ]}
          keys={["val"]}
          indexBy="key"
          margin={{ top: 50, right: 110, bottom: 50, left: 60 }}
          xScale={{ type: "point" }}
          yScale={{ type: "linear", min: "auto", max: "auto", stacked: true, reverse: false }}
          axisTop={null}
          axisRight={null}
          axisBottom={{
            orient: "bottom",
            tickSize: 5,
            tickPadding: 5,
            tickRotation: 0,
            legend: "value",
            legendOffset: 36,
            legendPosition: "middle"
          }}
          axisLeft={{
            orient: "left",
            tickSize: 5,
            tickPadding: 5,
            tickRotation: 0,
            legend: "Y axis",
            legendOffset: -40,
            legendPosition: "middle"
          }}
          colors={{ scheme: "nivo" }}
          pointSize={10}
          pointColor={{ theme: "background" }}
          pointBorderWidth={2}
          pointBorderColor={{ from: "serieColor" }}
          pointLabel="y"
          pointLabelYOffset={-12}
          useMesh={true}
        />
      )}
    </div>
  );
};

export default Chart;
